==> cfengine-1.4.1.tar.gz: cfengine-1.4.1/src/net.c <==
/* cfengine for GNU
 
        Copyright (C) 1995
        Free Software Foundation, Inc.
 
   This file is part of GNU cfengine - written and maintained 
   by Mark Burgess, Dept of Computing and Engineering, Oslo College,
   Dept. of Theoretical physics, University of Oslo
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

*/
 

/*********************************************************************/
/*                                                                   */
/*  TOOLKITS: network library                                        */
/*                                                                   */
/*********************************************************************/

#include "cf.defs.h"
#include "cf.extern.h"

/*************************************************************************/
 
 
TimeOut()
 
{
alarm(0);
Verbose("cfengine: Time out\n");
}
 
/*************************************************************************/
 
RecvSocketStream(sd,buffer,toget,nothing)
 
int sd,toget,nothing;
char *buffer;
 
{ int already, got;
 
for (already = 0; already != toget; already += got)
   {
   got = recv(sd,buffer+already,toget-already,0);
 
   if ((got == -1) || (got == 0))
      {
      return -1;
      }
 
   Debug("    (Concatenated %d from stream)\n",got);
   }
 
return toget;
}

==> cfengine-1.4.7.tar.gz: cfengine-1.4.7/src/net.c <==
/* cfengine for GNU
 
        Copyright (C) 1995
        Free Software Foundation, Inc.
 
   This file is part of GNU cfengine - written and maintained 
   by Mark Burgess, Dept of Computing and Engineering, Oslo College,
   Dept. of Theoretical physics, University of Oslo
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

*/
 

/*********************************************************************/
/*                                                                   */
/*  TOOLKITS: network library                                        */
/*                                                                   */
/*********************************************************************/

#include "cf.defs.h"
#include "cf.extern.h"

/*************************************************************************/
 
 
TimeOut()
 
{
alarm(0);
Verbose("cfengine: Time out\n");
}
 
/*************************************************************************/
 
RecvSocketStream(sd,buffer,toget,nothing)
 
int sd,toget,nothing;
char *buffer;
 
{ int already, got;
 
for (already = 0; already != toget; already += got)
   {
   got = recv(sd,buffer+already,toget-already,0);
 
   if (got == -1)
      {
      return -1;
      }
 
   if (got == 0)
      {
      return already;
      }

   if (strncmp(buffer,"AUTH",4) == 0 && (already == bufsize))
      {
      return already;
      }

   Debug("    (Concatenated %d from stream)\n",got);
   }
 
return toget;
}
